@@ -16,7 +16,7 @@ Net::LimeLight::Purge - LimeLight Purge Service API
 
 =cut
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,7 @@ our $VERSION = '0.02';
       username => 'luxuser',
       password => 'luxpass'
   );
-  my $ret = $puge->create_purge_request([ $req ]);
+  my $ret = $purge->create_purge_request([ $req ]);
   if($ret == -1) {
       say "Something broke!";
   } else {
@@ -173,6 +173,11 @@ The recipient to BCC the email to.
 sub create_purge_request {
     my ($self, $requests, $notification) = @_;
 
+    # If we are given nothing, do nothing.
+    if(!defined($requests) || (ref($requests) ne 'ARRAY') || (scalar(@{ $requests }) < 1)) {
+        return undef;
+    }
+
     # Set it to an empty hashref to save us some code.
     unless(defined($notification)) {
         $notification = {};
